function [Out,bDs,Errors]=set_linsolve_triu(N,verbose,varargin)
  % example of 'set_fun' function used in bench
  p = inputParser;
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('d',3,@isscalar);
  p.addParamValue('m',1,@isscalar);
  p.addParamValue('fprintf',@(varargin) fprintf(varargin{:}));
  p.addParamValue('rtype','array3d',@(s) ismember(lower(s),{'array3d','array2d'}));
  p.parse(varargin{:});
  R=p.Results;
  d=R.d;m=R.m;
  R.rtype=lower(R.rtype);
  Fprintf=R.fprintf;
  
  A=fc_linalg3D.random.randtriu(N,d,'a',1,'b',2);
  
  switch R.rtype
    case 'array3d'
        B=randn(N,d,m);
    case 'array2d'
        B=randn(d,m);
  end
  
  Errors={@(X) fc_linalg3D.solver.linsolve_error(A,X,B)};
  
  if verbose
    Fprintf('# Prototype functions: X=fun(A,B)\n');
    Fprintf('#   where A is a N-by-%d-by-%d 3D-array with regular triangular upper matrices.\n',d,d);
    Fprintf('# Computes X solutions of the linear systems:\n');
    if strcmp(R.rtype,'array2d')
      Fprintf('#     A_k * X_k = B    where A_k denotes squeeze(A(k,:,:))\n');
    else
      Fprintf('#     A_k * X_k = B_k    where A_k denotes squeeze(A(k,:,:))\n');
    end
    Fprintf('# Error[i] computed with fun[i] output :\n#  %s\n',func2str(Errors{1}));  
  end
  
  bDs{1}=fc_bench.bdata('N',N,'%d',10);
  Out={A,B};
end
